@@ -7,6 +7,88 @@ from .precomputed_exchange_calendar import PrecomputedExchangeCalendar
 
 precomputed_shanghai_holidays = pd.to_datetime(
     [
+        "1991-01-01",
+        "1991-02-15",
+        "1991-02-18",
+        "1991-05-01",
+        "1991-10-01",
+        "1991-10-02",
+        "1992-01-01",
+        "1992-02-04",
+        "1992-02-05",
+        "1992-02-06",
+        "1992-05-01",
+        "1992-10-01",
+        "1992-10-02",
+        "1993-01-01",
+        "1993-01-25",
+        "1993-01-26",
+        "1993-10-01",
+        "1994-02-07",
+        "1994-02-08",
+        "1994-02-09",
+        "1994-02-10",
+        "1994-02-11",
+        "1994-05-02",
+        "1994-10-03",
+        "1994-10-04",
+        "1995-01-02",
+        "1995-01-30",
+        "1995-01-31",
+        "1995-02-01",
+        "1995-02-02",
+        "1995-02-03",
+        "1995-05-01",
+        "1995-10-02",
+        "1995-10-03",
+        "1996-01-01",
+        "1996-02-19",
+        "1996-02-20",
+        "1996-02-21",
+        "1996-02-22",
+        "1996-02-23",
+        "1996-02-26",
+        "1996-02-27",
+        "1996-02-28",
+        "1996-02-29",
+        "1996-03-01",
+        "1996-05-01",
+        "1996-09-30",
+        "1996-10-01",
+        "1996-10-02",
+        "1997-01-01",
+        "1997-02-03",
+        "1997-02-04",
+        "1997-02-05",
+        "1997-02-06",
+        "1997-02-07",
+        "1997-02-10",
+        "1997-02-11",
+        "1997-02-12",
+        "1997-02-13",
+        "1997-02-14",
+        "1997-05-01",
+        "1997-05-02",
+        "1997-06-30",
+        "1997-07-01",
+        "1997-10-01",
+        "1997-10-02",
+        "1997-10-03",
+        "1998-01-01",
+        "1998-01-02",
+        "1998-01-26",
+        "1998-01-27",
+        "1998-01-28",
+        "1998-01-29",
+        "1998-01-30",
+        "1998-02-02",
+        "1998-02-03",
+        "1998-02-04",
+        "1998-02-05",
+        "1998-02-06",
+        "1998-05-01",
+        "1998-10-01",
+        "1998-10-02",
         "1999-01-01",
         "1999-02-10",
         "1999-02-11",
@@ -443,7 +525,11 @@ precomputed_shanghai_holidays = pd.to_datetime(
         "2022-02-02",
         "2022-02-03",
         "2022-02-04",
+        "2022-04-04",
         "2022-04-05",
+        "2022-05-02",
+        "2022-05-03",
+        "2022-05-04",
         "2022-06-03",
         "2022-10-03",
         "2022-10-04",
@@ -512,3 +598,7 @@ class XSHGExchangeCalendar(PrecomputedExchangeCalendar):
     @property
     def precomputed_holidays(self):
         return precomputed_shanghai_holidays
+
+    @property
+    def bound_start(self) -> pd.Timestamp:
+        return pd.Timestamp("1990-12-03", tz="Asia/Shanghai")
